==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lximage-qt/lximage-qt_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="89"/>
        <source>Take a screenshot</source>
        <translation>Ekran görüntüsü al</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="93"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="148"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="149"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation type="unfinished">LXImage - basit ve hızlı bir resim gösterici

Telif Hakkı (C) 2013
LXDE Projesi: http://lxde.org/

Yazarlar:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="242"/>
        <source>Open File</source>
        <translation>Dosya Aç</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Image files (%1)</source>
        <translation>Resim dosyaları (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Save File</source>
        <translation>Dosyayı Kaydet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="530"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Yükleniyor...) - Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="535"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Yükleme Başarısız Oldu) - Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="576"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="819"/>
        <source>Thumbnails</source>
        <translation>Küçükresimler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="159"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="169"/>
        <source>&amp;Open File</source>
        <translation>&amp;Dosya Aç</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>&amp;Save</source>
        <translation>&amp;Kaydet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="195"/>
        <source>Save &amp;As</source>
        <translation>&amp;Farklı Kaydet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="208"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="221"/>
        <source>Zoom &amp;In</source>
        <translation>Büyü&amp;t</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="234"/>
        <source>Zoom &amp;Out</source>
        <translation>Küç&amp;ült</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="247"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Panoya &amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="257"/>
        <location filename="../../mainwindow.ui" line="260"/>
        <source>Next File</source>
        <translation>Sonraki Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="273"/>
        <location filename="../../mainwindow.ui" line="276"/>
        <source>Previous File</source>
        <translation>Önceki Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Original Size</source>
        <translation>Özgün Boyut</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="299"/>
        <source>&amp;Fit</source>
        <translation>&amp;Uydur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="309"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Saat Yönüne Döndür</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="319"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Saat Yönünün &amp;Tersine Döndür</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="324"/>
        <source>P&amp;references</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="329"/>
        <source>&amp;Print</source>
        <translation>Ya&amp;zdır</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="332"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="342"/>
        <source>First File</source>
        <translation>İlk Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="345"/>
        <source>Home</source>
        <translation>Ev</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="355"/>
        <source>Last File</source>
        <translation>Son Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="358"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="368"/>
        <source>&amp;New Window</source>
        <translation>&amp;Yeni Pencere</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="376"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Yatay Çevir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="386"/>
        <source>Capture Screenshot</source>
        <translation>Ekran Görüntüsü Yakala</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="394"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="402"/>
        <source>Flip &amp;Vertically</source>
        <translation>Dikey Çe&amp;vir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="412"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Panodan Yapıştır</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="425"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Slayt Gösterisi</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="435"/>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="438"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="446"/>
        <source>Show Thumbnails</source>
        <translation>Küçükresimleri Göster</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="451"/>
        <source>File Properties</source>
        <translation>Dosya Özellikleri</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="77"/>
        <source>Go</source>
        <translation>Git</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="86"/>
        <source>&amp;View</source>
        <translation>G&amp;örünüm</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="100"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>Toolbar</source>
        <translation>Araç Çubuğu</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Tercihler</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Simge seti teması:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normal arkaplan rengi:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Tam ekran arkaplan rengi:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Slayt gösterisi aralığı (saniye):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="28"/>
        <source>Take a screenshot</source>
        <translation>Ekran görüntüsü al</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="35"/>
        <source>Region</source>
        <translation>Bölge</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="41"/>
        <source>Whole screen</source>
        <translation>Tüm ekran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="51"/>
        <source>Current window only</source>
        <translation>Sadece geçerli pencere</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="61"/>
        <source>Include mouse cursor</source>
        <translation>Fare imlecini de al</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="68"/>
        <source> seconds</source>
        <translation> saniye</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="85"/>
        <source>Delay:</source>
        <translation>Geçikme:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="95"/>
        <source>Include window title and frame</source>
        <translation>Pencere başlığı ve çerçevesini dahil et</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lximage-qt/lximage-qt_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="91"/>
        <source>Take a screenshot</source>
        <translation>Ekran görüntüsü al</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="95"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FILE1, FILE2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="143"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="144"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation type="unfinished">LXImage - basit ve hızlı bir resim gösterici

Telif Hakkı (C) 2013
LXDE Projesi: http://lxde.org/

Yazarlar:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="253"/>
        <source>Open File</source>
        <translation>Dosya Aç</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="254"/>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Image files (%1)</source>
        <translation>Resim dosyaları (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="260"/>
        <source>Open directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Save File</source>
        <translation>Dosyayı Kaydet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="537"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Yükleniyor...) - Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="542"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Yükleme Başarısız Oldu) - Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="546"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="582"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="842"/>
        <source>Thumbnails</source>
        <translation>Küçükresimler</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Resim Gösterici</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="160"/>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="170"/>
        <source>&amp;Open File</source>
        <translation>&amp;Dosya Aç</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="173"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="183"/>
        <source>&amp;Save</source>
        <translation>&amp;Kaydet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="186"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="196"/>
        <source>Save &amp;As</source>
        <translation>&amp;Farklı Kaydet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="199"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="212"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="222"/>
        <source>Zoom &amp;In</source>
        <translation>Büyü&amp;t</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="225"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="235"/>
        <source>Zoom &amp;Out</source>
        <translation>Küç&amp;ült</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="238"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="248"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>Panoya &amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="258"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Next File</source>
        <translation>Sonraki Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="264"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <location filename="../../mainwindow.ui" line="277"/>
        <source>Previous File</source>
        <translation>Önceki Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="280"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="290"/>
        <source>Original Size</source>
        <translation>Özgün Boyut</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="293"/>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="303"/>
        <source>&amp;Fit</source>
        <translation>&amp;Uydur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="313"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Saat Yönüne Döndür</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="323"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Saat Yönünün &amp;Tersine Döndür</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="328"/>
        <source>P&amp;references</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="333"/>
        <source>&amp;Print</source>
        <translation>Ya&amp;zdır</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="346"/>
        <source>First File</source>
        <translation>İlk Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="349"/>
        <source>Home</source>
        <translation>Ev</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="359"/>
        <source>Last File</source>
        <translation>Son Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="362"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="372"/>
        <source>&amp;New Window</source>
        <translation>&amp;Yeni Pencere</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="375"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="380"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Yatay Çevir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="390"/>
        <source>Capture Screenshot</source>
        <translation>Ekran Görüntüsü Yakala</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="398"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Tam Ekran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="401"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="406"/>
        <source>Flip &amp;Vertically</source>
        <translation>Dikey Çe&amp;vir</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="416"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Panodan Yapıştır</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="429"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Slayt Gösterisi</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="439"/>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="442"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="450"/>
        <source>Show Thumbnails</source>
        <translation>Küçükresimleri Göster</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="455"/>
        <source>File Properties</source>
        <translation>Dosya Özellikleri</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="463"/>
        <source>Open &amp;Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="466"/>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Git</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>G&amp;örünüm</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="121"/>
        <source>Toolbar</source>
        <translation>Araç Çubuğu</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Tercihler</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Simge seti teması:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normal arkaplan rengi:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Tam ekran arkaplan rengi:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Slayt gösterisi aralığı (saniye):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Ekran görüntüsü al</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Bölge</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Tüm ekran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Sadece geçerli pencere</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Fare imlecini de al</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> saniye</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Geçikme:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Pencere başlığı ve çerçevesini dahil et</translation>
    </message>
</context>
</TS>
